# frozen_string_literal: true

require_relative "retention/version"
require "date"

module Retention
  class Error < StandardError; end
  class Plan  
    STANDARD_PLAN = "standard"
    GOLD_PLAN  = "gold"
    PLATINUM_PLAN = "platinum"
    PLANS = %w(standard gold platinum)

    def self.calculate_deletion_date (plan, creation_date)
      if PLANS.include?(plan)
        if plan == STANDARD_PLAN
          handle_standard_plan (creation_date);
        elsif plan == GOLD_PLAN
          handle_gold_plan (creation_date);
        elsif plan == PLATINUM_PLAN
          handle_platinum_plan (creation_date);
        end
      else
        raise "This plan is not valid"
      end
    end

    def self.handle_standard_plan creation_date
      creation_date + 42
    end

    def self.handle_gold_plan creation_date
      if creation_date.month == creation_date.next_day.month 
        creation_date + 42
      else
        creation_date.next_month(12)
      end
    end

    def self.handle_platinum_plan creation_date
      if creation_date.year != creation_date.next_day.year
        creation_date.next_year(7)
      elsif creation_date.month != creation_date.next_day.month
        creation_date.next_month(12)
      else
        creation_date + 42
      end
    end
  end
end
